\name{Cc}
\alias{Cc}
\docType{data}
\title{ Microarray time series experiment 
for Caulobacter crescentus bacterial cell cycle}
\description{
In this microarray experiment there are 3062 genes 
or more correctly ORFs (open reading frames) that were
measured every 1 hour.
There are 19 is missing gene labels and these have been given labels ORFna1,...,ORFna19.
There 310 with duplicate labels.
Of these duplicate labels, 295 are duplicated twice, 12 are duplicated 3 times
and 3 are duplicated 4 times.
Duplicate labels are renamed ORF... to ORF...a and ORF...b etc.
This dataset is similar to \code{caulobacter} in the package
GeneCycle except \code{caulobacter} only has 1444 columns and 11 rows
whereas \code{Cc} has 3062 rows and 11 columns.
All genes with one or more missing values were removed from the
\code{caulobacter} dataset.
}

\usage{data(Cc)}

\format{
Matrix with 3062 rows and 11 columns.
Some missing data.
Rows and columns are labelled.
 - attr(*, "dimnames")=List of 2
  ..$ : chr [1:3062] "ORF06244a" "ORF03152a" "ORF03156a" "ORF03161a" ...
  ..$ : chr [1:11] "1" "2" "3" "4" ...
}

\details{
Gene expression from synchronized cultures of the bacterium 
Caulobacter crescentus (Laub et al., 2000).
(Laub et al., 2000) identified 553 genes whose
messenger RNA levels varied as a function of the cell cycle but their
statistical analysis was not very sophisticated and they probably 
identified too many genes.
}
\source{
http://caulobacter.stanford.edu/CellCycle/DownloadData.htm
}

\references{
Laub, M.T., McAdams,H.H., Feldblyum,T., Fraser,C.M. and Shapiro,L. (2000)
Global analysis of the genetic network controlling a bacterial cell cycle Science,
290, 2144-2148.

Wichert,S., Fokianos K. and Strimmer K. (2004) Identifying periodically expressed
transcrips in microarray time series data. Bioinformatics, 18, 5-20.

Miika Ahdesmaki, Konstantinos Fokianos, and Korbinian Strimmer (2009).
GeneCycle. This is package is available on CRAN. 
\url{http://CRAN.R-project.org/package=GeneCycle}.
See also,
\url{http://www.cs.tut.fi/~ahdesmak/robustperiodic/}. 
}

\examples{
#Gene ORF06806 has strong periodicity is not detected by Fisher g test
#It is detected by our approach
z<-Cc[3034,]
ORF<-dimnames(Cc)[[1]]
ORF[3034]
plot(z, sub=paste("gene: ", ORF[3034]))
ans<-PeriodicityTest(z)
ans	  #p-value = 0.0002
FisherGTest(z) #p-value = 0.119
#
#Comparing with GeneCycle. 
#Don't try to run this example unless you have downloaded 'GeneCycle'!!
#Gene ORF06806 corresponds to column 1437 in 'caulobacter'
#and to row 3034 in Cc
#Verifying data for ORF06806 is the same is both packages
\dontrun{
all(caulobacter[,"ORF06806"]==Cc[3034,])
pval.caulobacter <- fisher.g.test(caulobacter)
pval.caulobacter[1437] #about 11% agrees with out approach
spe1437 = robust.spectrum(caulobacter[,1437])
pval = robust.g.test(spe1437) #about 0.010, so much better
}
}
\keyword{datasets}

