\name{GetFitHReg}
\alias{GetFitHReg}

\title{Compute loglikelihood ratio test statistic }

\description{
The loglikelihood ratio test statistic is computed for testing for periodicity
}

\usage{
GetFitHReg(y, t, nf=150)
}
\arguments{
  \item{y}{ vector containing the series }
  \item{t}{ vector of corresponding time points }
  \item{nf}{ nf, number of frequencies to enumerate }
}
\details{
This function interfaces with C code for fast evaluation.
}
\value{
LR statistic and
estimated frequency
}

\author{A.I. McLeod and M.S. Islam}

\references{
Islam, M.S. (2008).  
Peridocity, Change Detection and Prediction in Microarrays. 
Ph.D. Thesis, The University of Western Ontario. 
}


\examples{
#Simple Examples
z<-SimulateHReg(10, f=2.5/10, 1, 2)
GetFitHReg(z)
t<-seq(2,20,2)
GetFitHReg(y=z, t=t)
GetFitHReg(z, nf=25)

#Complicated Example
#Find all cases with 1 missing value
ind<-apply(Cc,MARGIN=1, function(x) sum(is.na(x))==1)
#there are lots, 3062 cases 
length(ind)
#the first one is ORF07082
ind[ind][1]
#Extract the series from Cc
z<-Cc["ORF07082",]
t<-1:length(z)
NotNA<-!is.na(z)
t<-t[NotNA]
z<-z[NotNA]
cbind(t,z)
#In this case, the missing data point corresponds to last observation.
#This is not so interesting because it could be treated as a complete
#series of length 10 rather than 11
#now let's try to find a series with a missing value not at the end
jnd<-apply(Cc[ind,], MARGIN=1, function(x) !is.na(x[11]))
#there is only one, ORF06139
jnd[jnd]
z<-Cc["ORF06139",]
t<-1:length(z)
NotNA<-!is.na(z)
t<-t[NotNA]
z<-z[NotNA]
cbind(t,z)
#In this case it is at the beginning of the series
#Let's try with 2 missing values and checking that there is one missing
#value surrounded by at least one actual value
ind<-apply(Cc,MARGIN=1, function(x) sum(is.na(x))==2)
#possible negative patterns are: 1:TF...FT,  2:TTF...F,  3:FF...FTT
jnd1<-apply(Cc[ind,], MARGIN=1, function(x) is.na(x[1]) & is.na(x[11]))
jnd2<-apply(Cc[ind,], MARGIN=1, function(x) is.na(x[1]) & is.na(x[2]))
jnd3<-apply(Cc[ind,], MARGIN=1, function(x) is.na(x[10]) & is.na(x[11]))
summary(jnd1)
summary(jnd2)
summary(jnd3)
jnd<- !(jnd1|jnd2|jnd3)
sum(jnd) #there are 62 cases
jnd[jnd][1] #the first one corresponds to ORF03148
#let's extract it
z<-Cc["ORF03148",]
t<-1:length(z)
NotNA<-!is.na(z)
t<-t[NotNA]
z<-z[NotNA]
cbind(t,z)
#So observations corresponds to t=3 and 11 are missing
#PeriodicityTest function handles missing values in input
PeriodicityTest(Cc["ORF03148",])
#GetPeriodicityTest is a lower level function.
#It must be supplied data with no missing values, as follows,
GetFitHReg(z,t)
}

\keyword{ ts }
